<?php

namespace Drupal\paragraphs_sort_alphabetically_widget\Plugin\Field\FieldWidget;

use Drupal\Core\Field\Attribute\FieldWidget;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\paragraphs\Plugin\Field\FieldWidget\ParagraphsWidget;

/**
 * Provides a Paragraphs widget with alphabetic sorting support.
 */
#[FieldWidget(
  id: "paragraphs_alpha_sort",
  label: new TranslatableMarkup('Paragraphs (sort alphabetically)'),
  field_types: ["entity_reference_revisions"]
)]
class ParagraphsAlphaSortWidget extends ParagraphsWidget {

  /**
   * {@inheritdoc}
   */
  public function formMultipleElements(FieldItemListInterface $items, array &$form, FormStateInterface $form_state): array {
    $element = parent::formMultipleElements($items, $form, $form_state);
    // Ensure Paragraphs styling/behavior applies.
    $element['#attributes']['class'][] = 'field--widget-paragraphs';

    // Add our own class for targeting.
    $element['#attributes']['class'][] = 'field--widget-paragraphs-alpha-sort';

    if (isset($element['add_more'])) {
      $element['add_more']['sort_alpha'] = [
        '#type' => 'button',
        '#value' => $this->t('Sort Alphabetically'),
        '#attributes' => [
          'class' => ['button--small button', 'paragraphs-sort-alpha'],
          'data-sort-field' => $items->getName(),
        ],
        '#weight' => 100,
      ];

      $element['#attached']['library'][] = 'paragraphs_sort_alphabetically_widget/sort_paragraphs';
    }

    return $element;
  }

}
